# json-db

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/json-db?style=flat-square) ![PyPI - Wheel](https://img.shields.io/pypi/wheel/json-db?style=flat-square) [![Hits](https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https%3A%2F%2Fgithub.com%2Fjoonas-yoon%2Fjson-db)](https://hits.seeyoufarm.com&style=flat-square)

![PyPI - Python Version](Python Version Badge)
![PyPI - Wheel](Wheel Badge)
[![Hits](Hits Badge)](Hits)

Using JSON as very lightweight database

## Installation

Installing via pip:

```
pip install json-db
```

Installing via GitHub repository,

```
git clone https://github.com/joonas-yoon/json-db.git
pip install -e json-db
```

## Contributing

Contributing guidelines can be found [CONTRIBUTING.md](CONTRIBUTING).

Welcome all contributions to the community and feel free to contribute.

## License

Under the MIT license. See the [LICENSE] file for more info.


[Python Version Badge]: https://img.shields.io/pypi/pyversions/json-db?style=flat-square
[Wheel Badge]: https://img.shields.io/pypi/wheel/json-db?style=flat-square
[Hits Badge]: https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https%3A%2F%2Fgithub.com%2Fjoonas-yoon%2Fjson-db
[Hits]: https://hits.seeyoufarm.com&style=flat-square
[CONTRIBUTING]: CONTRIBUTING.md
[LICENSE]: LICENSE
